Welcome to Radon’s documentation! — Radon 1.4.2 documentation

# Welcome to Radon’s documentation!

Radon is a Python tool which computes various code metrics. Supported metrics are:

> - raw metrics: SLOC, comment lines, blank lines, &c.
> - Cyclomatic Complexity (i.e. McCabe’s Complexity)
> - Halstead metrics (all of them)
> - the Maintainability Index (a Visual Studio metric)

Radon can be used either from the command line or programmatically through its API.

Contents:

- Introduction to Code Metrics
  - Cyclomatic Complexity
  - Maintainability Index
  - Raw Metrics
  - Halstead Metrics
  - Further Reading
- Command-line Usage
  - The cc command
  - The mi command
  - The raw command
- Flake8 plugin
- Using radon programmatically
  - Cyclomatic Complexity
  - Raw metrics
  - Other metrics
  - Visitors
  - Harvesters
- Changelog
  - 1.4.2 (Jul 26, 2016)
  - 1.4.0 (Jun 03, 2016)
  - 1.3.0 (Mar 02, 2016)
  - 1.2.2 (Jul 09, 2015)
  - 1.2.1 (May 07, 2015)
  - 1.2 (Jan 16, 2015)
  - 1.1 (Sep 6, 2014)
  - 1.0 (Aug 15, 2014)
  - 0.5.3 (Aug 1, 2014)
  - 0.5.2 (Jul 24, 2014)
  - 0.5.1 (Mar 4, 2014)
  - 0.5 (Feb 17, 2014)
  - 0.4.5 (Dec 16, 2013)
  - 0.4.4 (Nov 20, 2013)
  - 0.4.2 (Jun 25, 2013)
  - 0.4.1 (Jun 16, 2013)
  - 0.4 (Apr 26, 2013)
  - 0.3 (Nov 2, 2012)
  - 0.2 (Oct 11, 2012)
  - 0.1 (Never)

# Indices and tables

- Index
- Module Index
- Search Page